<?php
require_once("cwfUI.inc.php");

class KDbOptionsUI extends cwfUI {
  protected static $accessRight = "kdb_options";
  protected static $dataClass = "KDbOptions";
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // initialize
  public function __construct() {
    parent::__construct();
    $this->initialize();
  }
  
  protected function initialize() {
    parent::initialize();
    $this->header = "  <script type=\"text/javascript\" src=\"".KDbConfig::getCwfHttpPath()."cwf/js/cwfToggle.js\"></script>
  <script type=\"text/javascript\">
    $(document).ready(function(){
      $(\"form\").validate({
        errorClass: 'invalid',
        groups: { db_connection: 'db_host db_name db_user db_passwd' },\n".
        $this->data->validation->getValidationRulesJQuery("        ")."
      });
    });
  </script>\n";
    $this->title = _("K_Db Options");
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // handle data
  static public function getValidationRules() {
    $rules = array(
        "root_email"=>array("email"=>true),
        "db_host"=>array("required"=>true),
        "db_name"=>array("required"=>true),
        "db_user"=>array("required"=>true),
        "db_connection"=>array("required"=>true)
    );
    $messages = array(
        "root_email"=>_("Email address is not valid."),
        "db_host"=>array("required"=>_("You have to supply a hostname for the KDb database.")),
        "db_name"=>array("required"=>_("You have to supply the name of KDb database.")),
        "db_user"=>array("required"=>_("You have to supply a username for the KDb database.")),
        "db_connection"=>array("required"=>" ")
    );
    
    $validationRules = new FormValidation($rules, $messages);
    return $validationRules;
  }
  
  public function isValid($action) {
    return $this->data->validation->isValid();
  }
  
  public function getInvalidFields() {
    return $this->data->validation->getInvalidMessages();
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // output
  public function getHTMLnoForm() {
?>
<h3 class="first"><?=_("K_Db Options")?></h3>

<p>
  <label for="organisation_name"><?=_("Name of the organisation")?>:</label>
  <input type="text" id="organisation_name" name="organisation_name" value="<?=$this->data->organisation_name?>">
    <span id="tt_organisation_name" class="tooltip"><?=_("The name of the organisation is used in the subject of various automatic emails (e.g. if users forget their passwords). The receipient of such an email can more easily identify the sender.")?></span>
</p>

<p>
  <label for="root_email"><?=_("Email address of <i>root</i>")?>:</label>
  <input type="text" id="root_email" name="root_email" value="<?=$this->data->root_email?>">
</p>

<p>
  <label for="allow_user_login"><?=_("Allow user login")?>:</label>
  <input type="checkbox" id="allow_user_login" name="allow_user_login" value="1"<?= (($this->data->allow_user_login) ? " checked" : "")?>>
    <span id="tt_allow_user_login" class="tooltip"><?=_("Allow registered users to log in and change their data and book events.")?></span>
</p>

<p>
  <label for="disable_file_upload"><?=_("Deactivate file upload")?>:</label>
  <input type="checkbox" id="disable_file_upload" name="disable_file_upload" value="1"<?=(($this->data->disable_file_upload) ? " checked" : "")?>>
    <span id="tt_disable_file_upload" class="tooltip"><?=_("The configuration options for file uploads under events / forms are not shown. File upload is disabled.")?></span>
</p>

<p>
  <label for="enable_multiple_registration"><?=_("Enable multiple registration")?>:</label>
  <input type="checkbox" id="enable_multiple_registration" name="enable_multiple_registration" value="1"<?=(($this->data->enable_multiple_registration) ? " checked" : "")?>>
    <span id="tt_enable_multiple_registration" class="tooltip"><?=_("Users can register multiple times for a single event, if this option is active. Multiple registrations have to be enabled for each event.")?></span>
</p>

<p>
  <label for="email_duplicates"><?=_("Duplicate email address")?>:</label>
  <select id="email_duplicates" name="email_duplicates">
    <option value="<?=EMAIL_DONT_CHECK?>"<?=(($this->data->email_duplicates==EMAIL_DONT_CHECK) ? " selected" : "")?>><?= _("allow") ?></option>
    <option value="<?=EMAIL_CHECK_EVENT?>"<?=(($this->data->email_duplicates==EMAIL_CHECK_EVENT) ? " selected" : "")?>><?= _("do not allow within the same event") ?></option>
    <option value="<?=EMAIL_ALWAYS_CHECK?>"<?=(($this->data->email_duplicates==EMAIL_ALWAYS_CHECK) ? " selected" : "")?>><?= _("do not allow") ?></option>
  </select>
    <span id="tt_email_duplicates" class="tooltip"><?=_("This option defines if multiple registrations with the same email address are possible. If you choose 'do not allow' or 'do not allow within the same event' and an entry with the same email address exists, the user is informed. In this case registration is not possible until the user changes the email address.")?></span>
</p>

<p>
  <label for="css_skin"><?=_("Skin (CSS)")?>:</label>
  <select id="css_skin" name="css_skin">
    <option value=""<?=(($this->data->css_skin=="") ? " selected" : "")?>><?= _("Default") ?></option>
<?php 
    $dir  = opendir(KDbConfig::getCwfPath()."k_db/css/skins");
    $files = array();
    while (($filename = readdir($dir))!==false) {
      if(substr($filename, -9)=="_user.css")
        $files[] = substr($filename, 0, -9);
    }
    sort($files);
    foreach($files as $file)
      echo "    <option value=\"$file\"".(($this->data->css_skin==$file) ? " selected" : "").">".ucwords($file)."</option>\n";
?>
  </select>
</p>

<p>
  <label for="force_language"><?=_("Force language")?>:</label>
  <select id="force_language" name="force_language">
    <option value=""<?=(($this->data->force_language=="") ? " selected" : "")?>><?= _("no") ?></option>
<?php 
    foreach(CWFMainUI::allowedLanguages() as $lang)
      echo "    <option value=\"$lang\"".(($this->data->force_language==$lang) ? " selected" : "").">{$lang}</option>\n";
?>
  </select>
    <span id="tt_force_language" class="tooltip"><?=_("Sets the language of the user interface (for users and admins) to the chosen language. If set to &quot;no&quot; the language setting of the web browser will be used.")?></span>
</p>

<h3><?=_("Database settings")?> <input type="hidden" id="db_connection" name="db_connection" value="1"><label class="invalid" for="db_connection" generated="true" style="display:none;"></label></h3>

<p>
  <label for="db_host"><?=_("Host")?>:</label>
  <input type="text" id="db_host" name="db_host" value="<?=$this->data->db_host?>">
    <span id="tt_db_host" class="tooltip"><?=_("The ip address of the server, where the database is on.")?></span>
</p>

<p>
  <label for="db_name"><?=_("Database name")?>:</label>
  <input type="text" id="db_name" name="db_name" value="<?=$this->data->db_name?>">
    <span id="tt_db_name" class="tooltip"><?=_("The name of the database.")?></span>
</p>

<p>
  <label for="db_user"><?=_("User")?>:</label>
  <input type="text" id="db_user" name="db_user" value="<?=$this->data->db_user?>">
    <span id="tt_db_user" class="tooltip"><?=_("A user, that is allowed to connect to the dabase and has the following permissions: SELECT, INSERT, UPDATE, DELETE, CREATE, ALTER, DROP.")?></span>
</p>

<p>
  <label for="db_passwd"><?=_("Password")?>:</label>
  <input type="password" id="db_passwd" name="db_passwd" value="<?=$this->data->db_passwd?>">
    <span id="tt_db_passwd" class="tooltip"><?=_("The password of the user.")?></span>
</p>

<h3><?=_("Security settings")?></h3>

<p>
  <label for="admin_login_mode"><?=_("Access to admin pages")?>:</label>
  <select id="admin_login_mode" name="admin_login_mode"<?=((THIS_FILE=="setup.php") ? "readonly" : "")?>>
    <option value="<?=LOGIN_MODE_PASSWD?>"<?=(($this->data->admin_login_mode==LOGIN_MODE_PASSWD) ? " selected" : "")?>><?= CWFTools::getLoginModeStr(LOGIN_MODE_PASSWD) ?></option>
    <option value="<?=LOGIN_MODE_IP?>"<?=(($this->data->admin_login_mode==LOGIN_MODE_IP) ? " selected" : "")?>><?= CWFTools::getLoginModeStr(LOGIN_MODE_IP) ?></option>
    <option value="<?=LOGIN_MODE_IP_OR_PW?>"<?=(($this->data->admin_login_mode==LOGIN_MODE_IP_OR_PW) ? " selected" : "")?>><?= CWFTools::getLoginModeStr(LOGIN_MODE_IP_OR_PW) ?></option>
    <option value="<?=LOGIN_MODE_IP_AND_PW?>"<?=(($this->data->admin_login_mode==LOGIN_MODE_IP_AND_PW) ? " selected" : "")?>><?= CWFTools::getLoginModeStr(LOGIN_MODE_IP_AND_PW) ?></option>
  </select>
    <span id="tt_admin_login_mode" class="tooltip"><?=_("Determines how admins are authenticated. Please remember to set allowed ip addresses before setting this option to 'IP address' or 'Username/PW and IP address'.")?></span>
</p>

<h3><?=_("Registration form")?></h3>

<p>
  <label for="currency"><?=_("Currency")?>:</label>
  <input type="text" id="currency" name="currency" value="<?=$this->data->currency?>">
    <span id="tt_currency" class="tooltip"><?=_("Currency displayed in booking forms.")?></span>
</p>

<p>
  <label for="confirmation_text"><?=_("Confirmation text")?>:</label>
  <textarea id="confirmation_text" name="confirmation_text"><?=$this->data->confirmation_text?></textarea><br>
  <span class="form_additional_info"><b>Variables:</b> $FORM_DATA$ (<?=_("prints the data entered in the registration form")?>), $salutation$, $givenname$, $familyname$, $user_id$, $passwd$, $booked_program$, $grandtotal$</span>
    <span id="tt_confirmation_text" class="tooltip"><?=_("This text is displayed after registration. The optional variables are replaced with the data entered by the user.")?></span>
</p>

<p>
  <label for="confirmation_email"><?=_("Text for confirmation email")?>:</label>
  <textarea id="confirmation_email" name="confirmation_email"><?=$this->data->confirmation_email?></textarea><br>
  <span class="form_additional_info"><b>Variables:</b> $FORM_DATA$ (<?=_("prints the data entered in the registration form")?>), $salutation$, $givenname$, $familyname$, $user_id$, $passwd$, $booked_program$, $grandtotal$</span>
    <span id="tt_confirmation_email" class="tooltip"><?=_("This text is used in the confirmation email after registration. The optional variables are replaced with the data entered by the user.")?></span>
</p>

<div class="toggle">
  <div class="toggle_part toggle_available">
    <div><?=_("Available fields")?>:</div>
    <ul>
<?php
    $propertyId = array();
    $propertyCounter = 0;
    foreach (User::getPropertiesUserInput() as $property => $name) {
      if(!in_array($property, $this->data->user_properties))
        echo "      <li name=\"toggle_{$propertyCounter}\">{$name}<input type=\"hidden\" name=\"user_properties[]\" value=\"$property\" disabled>".
             "<input type=\"checkbox\" name=\"user_properties_req[]\" value=\"$property\" disabled></li>\n";
      $propertyId[$property] = $propertyCounter++;
    }
?>
    </ul>
  </div><div class="toggle_control"><span class="toggle_add">&raquo;</span><br><span class="toggle_remove">&laquo;</span></div><div class="toggle_part toggle_selected">
    <div><?=_("Selected fields")?>:</div>
    <ul>
<?php
    foreach (User::getPropertiesUserInput() as $property => $name) {
      if(in_array($property, $this->data->user_properties))
        echo "      <li name=\"toggle_{$propertyId[$property]}\">{$name}<input type=\"hidden\" name=\"user_properties[]\" value=\"$property\">".
             "<input type=\"checkbox\" name=\"user_properties_req[]\" value=\"$property\"".((in_array($property, $this->data->user_properties_req)) ? " checked" : "")."></li>\n";
    }
?>
    </ul>
  </div><div class="toggle_control"><span class="toggle_up">&uArr;</span><br><span class="toggle_down">&dArr;</span></div>
</div>
<span id="tt_user_properties_req" class="tooltip"><?=_("Mandatory field.")?></span>

<h3><?=_("Miscellaneous settings")?></h3>

<p>
  <label for="returnpath_workaround"><?=_("Return-Path workaround")?>:</label>
  <input type="checkbox" id="returnpath_workaround" name="returnpath_workaround" value="1"<?= (($this->data->returnpath_workaround) ? " checked" : "")?>>
    <span id="tt_returnpath_workaround" class="tooltip"><?=_("Use -f option to set the return path when sending emails. Some MTAs (e. g. Postfix) ignore the header 'Return-Path'. To set the return path to the sender's email address the -f option has to be used in this case.")?></span>
</p>

<?php    
  }
  
  public function getHTML(DbConnection $DB) {
?>
<form id="kdb_form" action="" method="post" enctype="multipart/form-data">
<div class="form_controls_top">
<p>
  <input type="submit" id="kdb_save" name="kdb_save" value="<?=_("Save")?>" onClick="kdbSaveEntry('KDbOptionsUI', 'save'); return false;">
</p>
</div>

<?php
    $this->getHTMLnoForm();
?>

<div class="form_controls_bottom">
<p>
  <input type="submit" id="kdb_save2" name="kdb_save" value="<?=_("Save")?>" onClick="kdbSaveEntry('KDbOptionsUI', 'save'); return false;">
</p>
</div>
</form>
<?php
  }
}

?>