<?php
define("CWF_VERSION", "1.0");

define("LOGIN_MODE_IP", 1);
define("LOGIN_MODE_PASSWD", 2);
define("LOGIN_MODE_IP_OR_PW", 3);
define("LOGIN_MODE_IP_AND_PW", 4);

class CWFTools {
  static public $SALT_LENGTH = 20;
  
  protected function __construct() {
  }
  
  static public function startSession($name, $path="") {
    if (session_id()=="") {   // if no active session we start a new one
      $path = "";
      session_name($name);
      if ($_SERVER['SERVER_NAME']!='localhost')
        session_set_cookie_params (0, KDbConfig::getCwfHttpPath().$path, $_SERVER['SERVER_NAME']);
      else
        session_set_cookie_params (0, KDbConfig::getCwfHttpPath().$path);
      session_start();
    }
  }
  
  static public function mb_strpad($input, $pad_length, $pad_string=" ", $pad_type=STR_PAD_RIGHT) {
    $strLen = mb_strlen($input);
    $strLenPad = mb_strlen($pad_string);
    if (!$pad_length || !$strLenPad || $pad_length <= $strLen) {
        return $input;
    }
   
    $result = null;
    $repeat = ceil(($pad_length-$strLen) / $strLenPad);
    switch($pad_type) {
      case STR_PAD_LEFT:
        $result = str_repeat($pad_string, $repeat) . $input;
        $result = mb_substr($result, -$pad_length);
        break;
      case STR_PAD_BOTH:
        $repeat = ceil($repeat / 2);
        $padLen = ($pad_length-$strLen) / 2;
        $result = mb_substr(str_repeat($pad_string, $repeat), 0, floor($padLen));
        $result .= $input;
        $result .= mb_substr(str_repeat($pad_string, $repeat), 0, ceil($padLen));
      case STR_PAD_RIGHT:
      default:
        $result = $input . str_repeat($pad_string, $repeat);
        $result = mb_substr($result, 0, $pad_length);
        break;
    }
   
    return $result;
  }
  
  static public function trimArray($a) {
    $tmpArray = $a; 
    array_walk($tmpArray, function(&$value){$value = trim($value);});
    
    return $tmpArray;
  }

  static public function replaceHTMLChars(&$a) {
    if (is_array($a)) {
      foreach ($a as &$value)
        self::replaceHTMLChars($value);
    }
    else {
      if(is_string($a)) {
        $tmp = stripslashes($a);
        $a = str_replace(array("&", "'", "\"", "<", ">"),
                         array("&amp;", "&#039;", "&quot;", "&lt;", "&gt;"),
                         $tmp);
      }
    }
  }

  static public function decodeHTMLChars(&$a) {
    if (is_array($a)) {
      foreach ($a as &$value)
        self::decodeHTMLChars($value);
    }
    else {
      if(is_string($a)) {
        $tmp = stripslashes($a);
        $a = str_replace(array("&amp;", "&#039;", "&quot;", "&lt;", "&gt;", "&minus;", "&nbsp;"),
                         array("&", "'", "\"", "<", ">", "-", " "),
                         $tmp);
      }
    }
  }
  
  static public function getHTMLDecodedStr($s) {
    if(is_string($s)) {
      static::decodeHTMLChars($s);
    }
    return $s;
  }

  static public function removeSuspiciousHTML($s) {
    if(is_string($s)) {
      $s = preg_replace('~<(script|iframe).*(</(script|iframe)[^>]*>)?~', '', stripslashes($s));
    }
    return $s;
  }
  
  static public function getLoginModeStr($loginMode) {
    $loginModeArray = array(1=>_("IP address"),
        2=>_("Username/Password"),
        3=>_("Username/PW or IP address"),
        4=>_("Username/PW and IP address")
      );

    return $loginModeArray[$loginMode];
  }
  
  static public function getPasswordHash($password, $hashAlgorithm="", $salt="") {
    $hashAlgorithms = array("sha512", "ripemd256", "md5");
    if(!$hashAlgorithm) { 
      $salt = substr(uniqid(rand(), true), 0, self::$SALT_LENGTH);
      if (function_exists('hash')) {
        foreach ($hashAlgorithms as $hashAlgorithm) {
          if (in_array($hashAlgorithm, hash_algos()))
            break;
        }
      }
      else
        $hashAlgorithm = "md5";
    }

    switch ($hashAlgorithm) {
      case "md5":
        return '$md5$'.$salt.md5($salt.$password);
        break;
      default:
        return '$'.$hashAlgorithm.'$'.$salt.hash($hashAlgorithm, $salt.$password);
    }
  }
  
  static public function generatePassword() {
    srand((double)microtime()*1000000);
    $chars1 = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
    $chars2 = "+-*/_#!$%&";
  
    $pw = "";
    $pw_length = rand(8, 10);
    while (strlen($pw) < $pw_length)
      $pw .= substr($chars1,(rand()%(strlen($chars1))),1);
  
    $pos = rand()%$pw_length;
    $pw[$pos] = substr($chars2,(rand()%(strlen($chars2))),1);
    
    return $pw;
  }
    
  static public function convertDate($date, $formatFrom, $formatTo) {
    if(!$date) return $date;
    $dateArr = date_parse_from_format($formatFrom, $date);
    if($dateArr['error_count']>0) return $date;
    if(intval($dateArr['month'])==0 && intval($dateArr['day'])==0 && intval($dateArr['year'])==0)
      return str_replace(array("d", "m", "Y"), array("00", "00", "0000"), $formatTo);
    return date($formatTo, mktime(0, 0, 0, intval($dateArr['month']), intval($dateArr['day']), intval($dateArr['year'])));
  }
  static public function dateLocal2ISO($date, $locale) {
    $dateFormat = array("en_US"=>"m/d/Y", "de_DE"=>"d.m.Y");
    
    return self::convertDate($date, $dateFormat[$locale], "Y-m-d");
  }
  static public function dateISO2Local($date, $locale) {
    $dateFormat = array("en_US"=>"m/d/Y", "de_DE"=>"d.m.Y");
    
    return self::convertDate($date, "Y-m-d", $dateFormat[$locale]);
  }
  
  static public function string2Float($string, $locale) {
    $decimalPoint = array("en_US"=>".", "de_DE"=>",");
    
    if($decimalPoint[$locale]!=".")
      return str_replace($decimalPoint[$locale], ".", $string);
    else
      return $string;
  }
  static public function float2String($float, $locale) {
    $decimalPoint = array("en_US"=>".", "de_DE"=>",");
    
    return str_replace(".", $decimalPoint[$locale], $float);
  }
  
  static public function generateFileName() {
    srand((double)microtime()*1000000);
    $chars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
    while (strlen($filename) < 12) { $filename .= substr($chars, (rand()%(strlen($chars))), 1); }
    return $filename;
  }
    
  static public function sanitizeFileName($filename, $removeSpace=true) {
    $specialChars = array("?", "[", "]", "/", "\\", "=", "<", ">", ":", ";", ",", "'", "\"", "&", "$", "#", "*", "(", ")", "|", "~", "`", "!", "{", "}");
    $filename = str_replace($specialChars, '', $filename);
    if($removeSpace)
      $filename = preg_replace('/[\s-]+/', '-', $filename);
    else
      $filename = preg_replace('/[\s]+/', ' ', $filename);
    $filename = trim($filename, '.-_ ');
    return $filename;
  }
  
  static public function sendEmail($emailAddr, $emailText, $emailSubject, $emailFrom, $emailBCC="") {
    if (trim($emailText) && $emailAddr) {
      self::decodeHTMLChars($emailText);
      $emailText = str_replace(array("\r\n", "\r"), "\n", $emailText);
      if($emailSubject) $emailSubject = $emailSubject = '=?utf-8?Q?'.preg_replace("~([^?])\=\r\n~", "$1?=\r\n=?utf-8?Q?", quoted_printable_encode(self::getHTMLDecodedStr($emailSubject))).'?=';
      $headers = "MIME-Version: 1.0\n";
      $headers .= "Content-type: text/plain; charset=utf-8\n";
      $headers .= "From: " . $emailFrom . "\nReply-To: " . $emailFrom . "\nReturn-Path: " . $emailFrom . "\n";
      if (isset($emailBCC) && $emailBCC)
        $headers .= "Bcc: " . $emailBCC . "\n";
      $parameters = "";
      if(KDbConfig::getReturnpathWorkaround() && KDbConfig::getReturnpathWorkaround()) 
        $parameters = "-f{$emailFrom}";
      mail($emailAddr, $emailSubject, $emailText, $headers, $parameters);
    }
  }

  static public function sendEmailWithAttachment($emailAddr, $emailText, $emailSubject, $emailFrom, $attachment, $emailBCC="") {
    if (trim($emailText) && $emailAddr) {
      self::decodeHTMLChars($emailText);
      $emailText = str_replace(array("\r\n", "\r"), "\n", $emailText);
      if($emailSubject) $emailSubject = '=?utf-8?Q?'.preg_replace("~([^?])\=\r\n~", "$1?=\r\n=?utf-8?Q?", quoted_printable_encode(self::getHTMLDecodedStr($emailSubject))).'?=';
      if($attachment) {
        $mimeBoundary = "==Multipart_Boundary_x".md5(time())."x";
        $headers = "MIME-Version: 1.0\n" .
            "Content-Type: multipart/mixed;\n" .
            " boundary=\"{$mimeBoundary}\"\n";
      }
      else
        $headers = "MIME-Version: 1.0\nContent-type: text/plain; charset=utf-8\n";
      if (isset($emailBCC) && $emailBCC)
        $headers .= "Bcc: " . $emailBCC . "\n";
      $headers .= "From: " . $emailFrom . "\nReply-To: " . $emailFrom . "\nReturn-Path: " . $emailFrom . "\n";

      if($attachment) {
        $emailText = "This is a multi-part message in MIME format.\n\n" .
            "--{$mimeBoundary}\n" .
            "Content-Type:text/plain; charset=\"utf-8\"\n" .
            "Content-Transfer-Encoding: 7bit\n\n" .
            $emailText . "\n\n".
            "--{$mimeBoundary}\n" .
            "Content-Type: {$attachment['type']};\n" .
            " name=\"{$attachment['name']}\"\n" .
            "Content-Transfer-Encoding: base64\n\n" .
            $attachment['data'] . "\n\n" .
            "--{$mimeBoundary}--\n";
      }
      
      $parameters = "";
      if(KDbConfig::getReturnpathWorkaround() && KDbConfig::getReturnpathWorkaround()) 
        $parameters = "-f{$emailFrom}";
      mail($emailAddr, $emailSubject, $emailText, $headers, $parameters);
    }
  }
}
?>
