<?php
require_once("cwfUI.inc.php");

class UserChangePwUI extends cwfUI {
  protected $error;
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // initialize
  public function __construct(DbConnection $DB) {
    parent::__construct();
    $this->initialize();

    if(isset($_POST['kdb_save']) && $_POST['kdb_save']) {
      $this->saveForm($DB);
    }
  }
  
  protected function initialize() {
    parent::initialize();
    if (isset($_SESSION['user'])) {
      $this->data = clone $_SESSION['user'];
      $this->data->setValidation(self::getValidationRules());
    }
    else
      $this->data = new User(self::getValidationRules());

    $this->header = "  <script type=\"text/javascript\">
    $(document).ready(function(){
      $(\"form\").validate({
        errorClass: 'invalid',\n".
        $this->data->validation->getValidationRulesJQuery("        ")."
      });
    });
  </script>\n";
    $this->title = _("Change password");
  }
  
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // security
  static public function isAllowedAction($action) {
    return in_array($action, array("changepw"));
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // handle data
  static public function getValidationRules() {
    $rules = array(
        "passwd"=>array("required"=>true),
        "passwd_repeat"=>array("required"=>true, "equalTo"=>"#passwd")
      );
    $messages = array(
        "passwd"=>array("required"=>_("Please enter a password")),
        "passwd_repeat"=>array("required"=>_("Please repeat the password."), "equalTo"=>_("Passwords do not match."))
      );
    
    $validationRules = new FormValidation($rules, $messages);
    return $validationRules;
  }
  
  public function getPostBackXML(DbConnection $DB, $action) {
    switch ($action) {
      case "changepw":
        if(isset($_SESSION['user'])) {
          $xml = $this->getNewValuesXML($this->data->getPostBackData());
        }
        break;
    }
    return $xml;
  }
  
  public function doAction(DbConnection $DB, $action) {
    $id = "";
    switch ($action) {
      case "changepw":
        $this->saveForm($DB);
        $id = $this->getId();
        break;
    }
    return $id;
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // Database operations
  public function saveForm(DbConnection $DB) {
    if($this->data->fromArray($_POST)) {
      list($errno, $error) = $this->data->changePW($DB);
      if ($errno) {
        $this->error = $error;
        return 0;
      }
      return 1;
    }
    $this->error = _("Validation failed.");
    return 0;
  }
  
  /////////////////////////////////////////////////////////////////////////////////////////////////
  // output
  public function getHTML(DbConnection $DB) {
?>
<form id="kdb_form" action="" method="post" enctype="multipart/form-data">
<h3 class="first"><?=_("Change password")?></h3>

<input type="hidden" id="user_id" name="user_id" class="id" value="<?= $this->data->user_id ?>">

<?php
    $classes = "class=\"required";
    if(!$this->data->validation->isValid("passwd"))
      $classes .= " error";
    $classes .= "\" ";
    echo "<p>\n";
    echo "  <label {$classes}for=\"passwd\">"._("Password").":</label>\n";
    echo "  <input {$classes}type=\"password\" id=\"passwd\" name=\"passwd\" value=\"\">\n";
    if(!$this->data->validation->isValid("passwd"))
      echo "  <label for=\"passwd\" class=\"invalid\">{$this->data->validation->getInvalidMessage('passwd')}</label>\n";
    echo "</p>\n\n";
    
    $classes = "class=\"required";
    if(!$this->data->validation->isValid("passwd_repeat"))
      $classes .= " error";
    $classes .= "\" ";
    echo "<p>\n";
    echo "  <label {$classes}for=\"passwd\">"._("Repeat password").":</label>\n";
    echo "  <input {$classes}type=\"password\" id=\"passwd_repeat\" name=\"passwd_repeat\" value=\"\">\n";
    if(!$this->data->validation->isValid("passwd_repeat"))
      echo "  <label for=\"passwd_repeat\" class=\"invalid\">{$this->data->validation->getInvalidMessage('passwd_repeat')}</label>\n";
    echo "</p>\n";
?>
<div class="form_controls_bottom">
<p>
  <input type="submit" id="kdb_save2" name="kdb_save" value="<?=_("Save")?>" onClick="kdbSaveEntry('UserChangePwUI', 'changepw'); return false;">
</p>
</div>
</form>
<?php
  }
}
?>
